@@ -28,7 +28,7 @@ class Network3Medusa():
         client = Client.forTestnet()
         client.setOperator(OPERATOR_ID, OPERATOR_KEY)
         tran = FileCreateTransaction()
-        resp = tran.setKeys(OPERATOR_KEY.getPublicKey()).setContents(raw_json).setMaxTransactionFee(Hbar(2)).execute(client)
+        resp = tran.setKeys(OPERATOR_KEY.getPublicKey()).setContents("test").setMaxTransactionFee(Hbar(2)).execute(client)
         print("nodeId: ",  resp.nodeId.toString())
         receipt = resp.getReceipt(client)
         fileId = receipt.fileId
